@@ -63,6 +63,8 @@ class RAFT_OMDAO(om.ExplicitComponent):
         nconnections = mooring_opt['nconnections']
 
         # turbine inputs
+        self.add_discrete_input('rotor_orientation', val='upwind', desc='Orientation of rotor relative to wind')
+
         self.add_input('turbine_mRNA', val=0.0, units='kg', desc='RNA mass')
         self.add_input('turbine_IxRNA', val=0.0, units='kg*m**2', desc='RNA moment of inertia about local x axis')
         self.add_input('turbine_IrRNA', val=0.0, units='kg*m**2', desc='RNA moment of inertia about local y or z axes')
@@ -294,7 +296,7 @@ class RAFT_OMDAO(om.ExplicitComponent):
                 if n in ['surge','sway','heave']:
                     myunit = 'm'
                 elif n in ['roll','pitch','yaw']:
-                    myunit = 'rad'
+                    myunit = 'deg'
                 elif n in ['AxRNA']:
                     myunit = 'm/s/s'
                 elif n in ['Mbase']:
@@ -328,6 +330,7 @@ class RAFT_OMDAO(om.ExplicitComponent):
         self.add_output("platform_displacement", 0.0, desc='Volumetric platform displacement', units='m**3')
         self.add_output("platform_mass", 0.0, units="kg")
         self.add_output("platform_I_total", np.zeros(6), units="kg*m**2")
+        self.add_output("dw_check", val=0, desc="Check for DW config")
         
         self.i_design = 0
         if modeling_opt['save_designs']:
@@ -354,6 +357,8 @@ class RAFT_OMDAO(om.ExplicitComponent):
         member_scalar_t = members_opt['scalar_thicknesses']
         member_scalar_d = members_opt['scalar_diameters']
         member_scalar_coeff = members_opt['scalar_coefficients']
+        intersectMesh = modeling_opt['intersection_mesh']
+
         
         nlines = mooring_opt['nlines']
         nline_types = mooring_opt['nline_types']
@@ -361,7 +366,7 @@ class RAFT_OMDAO(om.ExplicitComponent):
 
         # save inputs for RAFT testing/debugging
         if DEBUG_OMDAO:
-            from weis.aeroelasticse.FileTools import save_yaml
+            from openfast_io.FileTools import save_yaml
             # Options
             all_options = {}
             all_options['modeling_options']     = copy.deepcopy(self.options['modeling_options'])
@@ -400,23 +405,23 @@ class RAFT_OMDAO(om.ExplicitComponent):
 
         # Environment layer data
         design['site'] = {}
-        design['site']['water_depth'] = float(inputs['mooring_water_depth'])
-        design['site']['rho_air'] = float(inputs['rho_air'])
-        design['site']['rho_water'] = float(inputs['rho_water'])
-        design['site']['mu_air' ] = float(inputs['mu_air'])
-        design['site']['shearExp'] = float(inputs['shear_exp'])
+        design['site']['water_depth'] = float(inputs['mooring_water_depth'][0])
+        design['site']['rho_air'] = float(inputs['rho_air'][0])
+        design['site']['rho_water'] = float(inputs['rho_water'][0])
+        design['site']['mu_air' ] = float(inputs['mu_air'][0])
+        design['site']['shearExp'] = float(inputs['shear_exp'][0])
         
         # RNA properties
         design['turbine'] = {}
-        design['turbine']['mRNA']          = float(inputs['turbine_mRNA'])
-        design['turbine']['IxRNA']         = float(inputs['turbine_IxRNA'])
-        design['turbine']['IrRNA']         = float(inputs['turbine_IrRNA'])
-        design['turbine']['xCG_RNA']       = float(inputs['turbine_xCG_RNA'])
-        design['turbine']['hHub']          = float(inputs['turbine_hHub'])
-        design['turbine']['overhang']      = float(inputs['turbine_overhang'])
-        design['turbine']['Fthrust']       = float(inputs['turbine_Fthrust'])
-        design['turbine']['yaw_stiffness'] = float(inputs['turbine_yaw_stiffness'])
-        design['turbine']['gear_ratio']    = float(inputs['gear_ratio'])
+        design['turbine']['mRNA']          = float(inputs['turbine_mRNA'][0])
+        design['turbine']['IxRNA']         = float(inputs['turbine_IxRNA'][0])
+        design['turbine']['IrRNA']         = float(inputs['turbine_IrRNA'][0])
+        design['turbine']['xCG_RNA']       = float(inputs['turbine_xCG_RNA'][0])
+        design['turbine']['hHub']          = float(inputs['turbine_hHub'][0])
+        design['turbine']['overhang']      = float(inputs['turbine_overhang'][0]) * (-1 if discrete_inputs['rotor_orientation'] == 'upwind' else 1)
+        design['turbine']['Fthrust']       = float(inputs['turbine_Fthrust'][0])
+        design['turbine']['yaw_stiffness'] = float(inputs['turbine_yaw_stiffness'][0])
+        design['turbine']['gear_ratio']    = float(inputs['gear_ratio'][0])
 
         # Tower
         design['turbine']['tower'] = {}
@@ -432,32 +437,32 @@ class RAFT_OMDAO(om.ExplicitComponent):
         design['turbine']['tower']['gamma'] = inputs['turbine_tower_gamma'][0]
         design['turbine']['tower']['stations'] = inputs['turbine_tower_stations']
         if turbine_opt['scalar_diameters']:
-            design['turbine']['tower']['d'] = float(inputs['turbine_tower_d'])
+            design['turbine']['tower']['d'] = float(inputs['turbine_tower_d'][0])
         else:
             design['turbine']['tower']['d'] = inputs['turbine_tower_d']
         if turbine_opt['scalar_thicknesses']:
-            design['turbine']['tower']['t'] = float(inputs['turbine_tower_t'])
+            design['turbine']['tower']['t'] = float(inputs['turbine_tower_t'][0])
         else:
             design['turbine']['tower']['t'] = inputs['turbine_tower_t']
         if turbine_opt['scalar_coefficients']:
-            design['turbine']['tower']['Cd'] = float(inputs['turbine_tower_Cd'])
-            design['turbine']['tower']['Ca'] = float(inputs['turbine_tower_Ca'])
-            design['turbine']['tower']['CdEnd'] = float(inputs['turbine_tower_CdEnd'])
-            design['turbine']['tower']['CaEnd'] = float(inputs['turbine_tower_CaEnd'])
+            design['turbine']['tower']['Cd'] = float(inputs['turbine_tower_Cd'][0])
+            design['turbine']['tower']['Ca'] = float(inputs['turbine_tower_Ca'][0])
+            design['turbine']['tower']['CdEnd'] = float(inputs['turbine_tower_CdEnd'][0])
+            design['turbine']['tower']['CaEnd'] = float(inputs['turbine_tower_CaEnd'][0])
         else:
             design['turbine']['tower']['Cd'] = inputs['turbine_tower_Cd']
             design['turbine']['tower']['Ca'] = inputs['turbine_tower_Ca']
             design['turbine']['tower']['CdEnd'] = inputs['turbine_tower_CdEnd']
             design['turbine']['tower']['CaEnd'] = inputs['turbine_tower_CaEnd']
-        design['turbine']['tower']['rho_shell'] = float(inputs['turbine_tower_rho_shell'])
+        design['turbine']['tower']['rho_shell'] = float(inputs['turbine_tower_rho_shell'][0])
 
         # Blades and rotors
         design['turbine']['nBlades']    = int(discrete_inputs['nBlades'])
-        design['turbine']['shaft_tilt'] = float(inputs['tilt'])
-        design['turbine']['precone']    = float(inputs['precone'])
-        design['turbine']['Zhub']       = float(inputs['wind_reference_height'])
-        design['turbine']['Rhub']       = float(inputs['hub_radius'])
-        design['turbine']['I_drivetrain']    = float(inputs['rotor_inertia'])
+        design['turbine']['shaft_tilt'] = float(inputs['tilt'][0]) * (-1 if discrete_inputs['rotor_orientation'] == 'upwind' else 1)
+        design['turbine']['precone']    = float(inputs['precone'][0]) * (-1 if discrete_inputs['rotor_orientation'] == 'upwind' else 1)
+        design['turbine']['Zhub']       = float(inputs['wind_reference_height'][0])
+        design['turbine']['Rhub']       = float(inputs['hub_radius'][0])
+        design['turbine']['I_drivetrain']    = float(inputs['rotor_inertia'][0])
 
         design['turbine']['blade'] = {}
         design['turbine']['blade']['geometry']    = np.c_[inputs['blade_r'],
@@ -465,9 +470,9 @@ class RAFT_OMDAO(om.ExplicitComponent):
                                                           inputs['blade_theta'],
                                                           inputs['blade_precurve'],
                                                           inputs['blade_presweep']]
-        design['turbine']['blade']['Rtip']        = float(inputs['blade_Rtip'])
-        design['turbine']['blade']['precurveTip'] = float(inputs['blade_precurveTip'])
-        design['turbine']['blade']['presweepTip'] = float(inputs['blade_presweepTip'])
+        design['turbine']['blade']['Rtip']        = float(inputs['blade_Rtip'][0])
+        design['turbine']['blade']['precurveTip'] = float(inputs['blade_precurveTip'][0])
+        design['turbine']['blade']['presweepTip'] = float(inputs['blade_presweepTip'][0])
         airfoil_pos = [float(ap) for ap in inputs['airfoils_position']]     # Cast to float for yaml saving purposes
         design['turbine']['blade']['airfoils']    = list(zip(airfoil_pos, turbine_opt['af_used_names']))
         # airfoils data
@@ -486,10 +491,10 @@ class RAFT_OMDAO(om.ExplicitComponent):
         design['turbine']['pitch_control']['GS_Angles']    = inputs['rotor_PC_GS_angles']
         design['turbine']['pitch_control']['GS_Kp']        = inputs['rotor_PC_GS_Kp']
         design['turbine']['pitch_control']['GS_Ki']        = inputs['rotor_PC_GS_Ki']
-        design['turbine']['pitch_control']['Fl_Kp']        = float(inputs['Fl_Kp'])
+        design['turbine']['pitch_control']['Fl_Kp']        = float(inputs['Fl_Kp'][0])
         design['turbine']['torque_control'] = {}
-        design['turbine']['torque_control']['VS_KP'] = float(inputs['rotor_TC_VS_Kp'])
-        design['turbine']['torque_control']['VS_KI'] = float(inputs['rotor_TC_VS_Ki'])
+        design['turbine']['torque_control']['VS_KP'] = float(inputs['rotor_TC_VS_Kp'][0])
+        design['turbine']['torque_control']['VS_KI'] = float(inputs['rotor_TC_VS_Ki'][0])
 
         # Operations
         design['turbine']['wt_ops'] = {}
@@ -501,6 +506,13 @@ class RAFT_OMDAO(om.ExplicitComponent):
         design['platform'] = {}
         design['platform']['potModMaster'] = int(modeling_opt['potential_model_override'])
         design['platform']['dlsMax'] = float(modeling_opt['dls_max'])
+        design['platform']["intersectMesh"] = intersectMesh
+        if intersectMesh==1:
+            design['platform']['characteristic_length_min'] = float(modeling_opt['characteristic_length_min'])
+            design['platform']['characteristic_length_max'] = float(modeling_opt['characteristic_length_max'])
+        else:
+            design['platform']['characteristic_length_min'] = 1.0
+            design['platform']['characteristic_length_max'] = 3.0
         # lowest BEM freq needs to be just below RAFT min_freq because of interpolation in RAFT
         if float(modeling_opt['min_freq_BEM']) >= modeling_opt['min_freq']:
             modeling_opt['min_freq_BEM'] = modeling_opt['min_freq'] - 1e-7
@@ -525,21 +537,29 @@ class RAFT_OMDAO(om.ExplicitComponent):
             mnpts = len(idx)
             rA = rA_0 + s_ghostA*(rB_0-rA_0)
             rB = rA_0 + s_ghostB*(rB_0-rA_0)
+            extensionA = np.linalg.norm(rA_0-rA)
+            extensionB = np.linalg.norm(rB_0-rB)
             design['platform']['members'][i]['name'] = m_name
             design['platform']['members'][i]['type'] = i + 2
             design['platform']['members'][i]['rA'] = rA
             design['platform']['members'][i]['rB'] = rB
+            design['platform']['members'][i]['extensionA'] = extensionA
+            design['platform']['members'][i]['extensionB'] = extensionB
             design['platform']['members'][i]['shape'] = m_shape
             design['platform']['members'][i]['gamma'] = float(inputs[m_name+'gamma'][0])
             design['platform']['members'][i]['potMod'] = members_opt[m_name+'potMod']
             design['platform']['members'][i]['stations'] = s_grid
             
+            mesh_size_ok = True
             # updated version to better handle 'diameters' between circular and rectangular members
             if m_shape == 'circ' or m_shape == 'square':
                 if member_scalar_d[i]:
                     design['platform']['members'][i]['d'] = [float(inputs[m_name+'d'])]*mnpts
                 else:
                     design['platform']['members'][i]['d'] = np.interp(s_grid, s_0, inputs[m_name+'d'])
+                if design['platform']['members'][i]['potMod']:
+                    if design['platform']['characteristic_length_max'] > np.min(design['platform']['members'][i]['d']):
+                        mesh_size_ok = False
             elif m_shape == 'rect':
                 if member_scalar_d[i]:
                     design['platform']['members'][i]['d'] = np.zeros([mnpts,2])
@@ -549,6 +569,12 @@ class RAFT_OMDAO(om.ExplicitComponent):
                     design['platform']['members'][i]['d'] = np.zeros([len(s_grid),2])
                     design['platform']['members'][i]['d'][:,0] = np.interp(s_grid, s_0, inputs[m_name+'d'][:,0])
                     design['platform']['members'][i]['d'][:,1] = np.interp(s_grid, s_0, inputs[m_name+'d'][:,1])
+                if design['platform']['members'][i]['potMod']:
+                    if design['platform']['characteristic_length_max'] > np.min(design['platform']['members'][i]['d']):
+                        mesh_size_ok = False
+            if not mesh_size_ok:
+                print(f"Mesh warning: charateristic length max might be too large for member {i+1} with scales {design['platform']['members'][i]['d']}. Check the output mesh to see if it is valid.")
+
             ''' original version of handling diameters
             if member_scalar_d[i]:
                 design['platform']['members'][i]['d'] = float(inputs[m_name+'d'])
@@ -556,23 +582,23 @@ class RAFT_OMDAO(om.ExplicitComponent):
                 design['platform']['members'][i]['d'] = np.interp(s_grid, s_0, inputs[m_name+'d'])
             '''
             if member_scalar_t[i]:
-                design['platform']['members'][i]['t'] = float(inputs[m_name+'t'])
+                design['platform']['members'][i]['t'] = float(inputs[m_name+'t'][0])
             else:
                 design['platform']['members'][i]['t'] = np.interp(s_grid, s_0, inputs[m_name+'t'])
             
             if m_shape == "circ":
                 if member_scalar_coeff[i]:
-                    design['platform']['members'][i]['Cd'] = float(inputs[m_name+'Cd'])
-                    design['platform']['members'][i]['Ca'] = float(inputs[m_name+'Ca'])
+                    design['platform']['members'][i]['Cd'] = float(inputs[m_name+'Cd'][0])
+                    design['platform']['members'][i]['Ca'] = float(inputs[m_name+'Ca'][0])
                 else:
                     design['platform']['members'][i]['Cd'] = np.interp(s_grid, s_0, inputs[m_name+'Cd'])
                     design['platform']['members'][i]['Ca'] = np.interp(s_grid, s_0, inputs[m_name+'Ca'])
             elif m_shape == "rect":
                 if member_scalar_coeff[i]:
-                    design['platform']['members'][i]['Cd'][0] = float(inputs[m_name+'Cd'][0])
-                    design['platform']['members'][i]['Cd'][1] = float(inputs[m_name+'Cd'][1])
-                    design['platform']['members'][i]['Ca'][0] = float(inputs[m_name+'Ca'][0])
-                    design['platform']['members'][i]['Ca'][1] = float(inputs[m_name+'Ca'][1])
+                    design['platform']['members'][i]['Cd'][0] = float(inputs[m_name+'Cd'][0][0])
+                    design['platform']['members'][i]['Cd'][1] = float(inputs[m_name+'Cd'][1][0])
+                    design['platform']['members'][i]['Ca'][0] = float(inputs[m_name+'Ca'][0][0])
+                    design['platform']['members'][i]['Ca'][1] = float(inputs[m_name+'Ca'][1][0])
                 else:
                     design['platform']['members'][i]['Cd'] = np.zeros([len(s_grid),2])
                     design['platform']['members'][i]['Ca'] = np.zeros([len(s_grid),2])
@@ -582,25 +608,25 @@ class RAFT_OMDAO(om.ExplicitComponent):
                     design['platform']['members'][i]['Ca'][:,1] = np.interp(s_grid, s_0, inputs[m_name+'Ca'][:,1])
 
             if member_scalar_coeff[i]:
-                design['platform']['members'][i]['CdEnd'] = float(inputs[m_name+'CdEnd'])
-                design['platform']['members'][i]['CaEnd'] = float(inputs[m_name+'CaEnd'])
+                design['platform']['members'][i]['CdEnd'] = float(inputs[m_name+'CdEnd'][0])
+                design['platform']['members'][i]['CaEnd'] = float(inputs[m_name+'CaEnd'][0])
             else:
                 design['platform']['members'][i]['CdEnd'] = np.interp(s_grid, s_0, inputs[m_name+'CdEnd'])
                 design['platform']['members'][i]['CaEnd'] = np.interp(s_grid, s_0, inputs[m_name+'CaEnd'])
-            design['platform']['members'][i]['rho_shell'] = float(inputs[m_name+'rho_shell'])
+            design['platform']['members'][i]['rho_shell'] = float(inputs[m_name+'rho_shell'][0])
             if mnreps > 0:
                 design['platform']['members'][i]['heading'] = inputs[m_name+'heading']
             if mnpts_lfill > 0:
                 design['platform']['members'][i]['l_fill'] = inputs[m_name+'l_fill']
                 design['platform']['members'][i]['rho_fill'] = inputs[m_name+'rho_fill']
-            if ( (mncaps > 0) or (inputs[m_name+'ring_spacing'] > 0) ):
+            if ( (mncaps > 0) or (inputs[m_name+'ring_spacing'][0] > 0) ):
                 # Member discretization
                 s_height = s_grid[-1] - s_grid[0]
                 # Get locations of internal structures based on spacing
-                ring_spacing = inputs[m_name+'ring_spacing']
+                ring_spacing = inputs[m_name+'ring_spacing'][0]
                 n_stiff = 0 if ring_spacing == 0.0 else int(np.floor(s_height / ring_spacing))
                 s_ring = (np.arange(1, n_stiff + 0.1) - 0.5) * (ring_spacing / s_height)
-                if s_ring:
+                if np.any(s_ring):
                     if not m_shape == 'rect':
                         d_ring = np.interp(s_ring, s_grid, design['platform']['members'][i]['d'])
                     else:
@@ -623,7 +649,7 @@ class RAFT_OMDAO(om.ExplicitComponent):
                     t_cap = t_cap[:-1]
                     di_cap = di_cap[:-1]
                 # Combine with ring stiffeners
-                if s_ring:
+                if np.any(s_ring):
                     s_cap = np.r_[s_ring, s_cap]
                     t_cap = np.r_[inputs[m_name+'ring_t']*np.ones(n_stiff), t_cap]
                     di_cap = np.r_[d_ring-2*inputs[m_name+'ring_h'], di_cap]
@@ -635,7 +661,7 @@ class RAFT_OMDAO(om.ExplicitComponent):
                     design['platform']['members'][i]['cap_d_in'] = di_cap[isort]
 
         design['mooring'] = {}
-        design['mooring']['water_depth'] = float(inputs['mooring_water_depth'])
+        design['mooring']['water_depth'] = float(inputs['mooring_water_depth'][0])
         design['mooring']['points'] = [dict() for m in range(nconnections)] #Note: doesn't work [{}]*nconnections
         for i in range(0, nconnections):
             pt_name = f'mooring_point{i+1}_'
@@ -652,20 +678,20 @@ class RAFT_OMDAO(om.ExplicitComponent):
             design['mooring']['lines'][i]['endA'] = mooring_opt[ml_name+'endA']
             design['mooring']['lines'][i]['endB'] = mooring_opt[ml_name+'endB']
             design['mooring']['lines'][i]['type'] = mooring_opt[ml_name+'type']
-            design['mooring']['lines'][i]['length'] = float(inputs[ml_name+'length'])
+            design['mooring']['lines'][i]['length'] = float(inputs[ml_name+'length'][0])
         design['mooring']['line_types'] = [dict() for m in range(nline_types)] #Note: doesn't work [{}]*nline_types
         for i in range(0, nline_types):
             lt_name = f'mooring_line_type{i+1}_'
             design['mooring']['line_types'][i]['name'] = mooring_opt[lt_name+'name']
-            design['mooring']['line_types'][i]['diameter'] = float(inputs[lt_name+'diameter'])
-            design['mooring']['line_types'][i]['mass_density'] = float(inputs[lt_name+'mass_density'])
-            design['mooring']['line_types'][i]['stiffness'] = float(inputs[lt_name+'stiffness'])
-            design['mooring']['line_types'][i]['breaking_load'] = float(inputs[lt_name+'breaking_load'])
-            design['mooring']['line_types'][i]['cost'] = float(inputs[lt_name+'cost'])
-            design['mooring']['line_types'][i]['transverse_added_mass'] = float(inputs[lt_name+'transverse_added_mass'])
-            design['mooring']['line_types'][i]['tangential_added_mass'] = float(inputs[lt_name+'tangential_added_mass'])
-            design['mooring']['line_types'][i]['transverse_drag'] = float(inputs[lt_name+'transverse_drag'])
-            design['mooring']['line_types'][i]['tangential_drag'] = float(inputs[lt_name+'tangential_drag'])
+            design['mooring']['line_types'][i]['diameter'] = float(inputs[lt_name+'diameter'][0])
+            design['mooring']['line_types'][i]['mass_density'] = float(inputs[lt_name+'mass_density'][0])
+            design['mooring']['line_types'][i]['stiffness'] = float(inputs[lt_name+'stiffness'][0])
+            design['mooring']['line_types'][i]['breaking_load'] = float(inputs[lt_name+'breaking_load'][0])
+            design['mooring']['line_types'][i]['cost'] = float(inputs[lt_name+'cost'][0])
+            design['mooring']['line_types'][i]['transverse_added_mass'] = float(inputs[lt_name+'transverse_added_mass'][0])
+            design['mooring']['line_types'][i]['tangential_added_mass'] = float(inputs[lt_name+'tangential_added_mass'][0])
+            design['mooring']['line_types'][i]['transverse_drag'] = float(inputs[lt_name+'transverse_drag'][0])
+            design['mooring']['line_types'][i]['tangential_drag'] = float(inputs[lt_name+'tangential_drag'][0])
         design['mooring']['anchor_types'] = [dict() for m in range(1)] #Note: doesn't work [{}]*anchor_types
         design['mooring']['anchor_types'][0]['name'] = 'drag_embedment'
         design['mooring']['anchor_types'][0]['mass'] = 1e3
@@ -743,7 +769,33 @@ class RAFT_OMDAO(om.ExplicitComponent):
         # option to run level 1 load cases
         if True: #processCases:
             model.analyzeCases(meshDir=modeling_opt['BEM_dir'])
+
+        # Plot mesh
+        if modeling_opt['plot_designs'] and intersectMesh:
+            try:
+                import trimesh
+                import matplotlib.pyplot as plt
+            except:
+                raise ImportError('trimesh not installed, please install trimesh to plot mesh')
             
+            mesh = trimesh.load(os.path.join(modeling_opt['BEM_dir'],"Input", "Platform.stl"))
+            # Create a figure and axes
+            fig = plt.figure()
+            ax = fig.add_subplot(111, projection='3d')
+
+            # Get mesh vertices and faces
+            verts = mesh.vertices
+            faces = mesh.faces
+
+            # Plot the mesh
+            ax.plot_trisurf(
+                verts[:, 0], verts[:, 1], faces, verts[:, 2],
+                color='lightblue', edgecolor='black', linewidth=0.2, alpha=0.8
+            )
+            ax.set_box_aspect([ub - lb for lb, ub in (getattr(ax, f'get_{a}lim')() for a in 'xyz')])
+            plt.savefig(os.path.join(modeling_opt['BEM_dir'],"mesh_plot.png"), pad_inches=0, dpi=300)
+            
+
         # get and process results
         results = model.calcOutputs()
         # Pattern matching for "responses" annd "properties"
@@ -808,7 +860,7 @@ class RAFT_OMDAO(om.ExplicitComponent):
         outputs["platform_I_total"][:3] = np.r_[outputs['properties_roll inertia at subCG'][0],
                                            outputs['properties_pitch inertia at subCG'][0],
                                            outputs['properties_yaw inertia at subCG'][0]]
-
+        outputs['dw_check'] = 1 if all([model.design['turbine'][x] > 0 for x in ['overhang','shaft_tilt','precone']]) else 0
         
 class RAFT_Group(om.Group):
     def initialize(self):
