@@ -52,13 +52,7 @@ class Rotor:
                 raise Exception("For designs with more than one rotor, the RNA reference point must be specified for each of them.")
             self.r_rel = [0, 0, 100.]
 
-        self.overhang   = getFromDict(turbine, 'overhang', shape=turbine['nrotors'])[ir]  # rotor offset in +x before yaw [m]
-        if self.overhang > 0:
-            print("WARNING: The turbine overhang input was positive for upwind turbines.")
-            print("The sign convention is now along +x (opposite of before)")
-            print("so that the specified overhang is a downwind rotor. Please flip the")
-            print("sign (negative overhang) if you wanted an upwind rotor.")
-            
+        self.overhang   = getFromDict(turbine, 'overhang', shape=turbine['nrotors'])[ir]  # rotor offset in +x before yaw [m]        
         self.xCG_RNA = getFromDict(turbine, 'xCG_RNA', shape=turbine['nrotors'])[ir]  # RNA CG offset in +x before yaw [m]
         
         # mass/inertia
@@ -85,8 +79,8 @@ class Rotor:
         default_azimuths    = list(np.arange(self.nBlades) * 360. / self.nBlades) # equally distribute blades
         self.azimuths       = getFromDict(turbine, 'headings', shape=-1, default=default_azimuths)  # [deg]
         
-        self.Rhub       = getFromDict(turbine, 'Rhub', shape=turbine['nrotors'])[ir]            # [m]
-        self.precone    = getFromDict(turbine, 'precone', shape=turbine['nrotors'])[ir]         # [m]
+        self.Rhub       = getFromDict(turbine, 'Rhub', shape=turbine['nrotors'])[ir]              # [m]
+        self.precone    = getFromDict(turbine, 'precone', shape=turbine['nrotors'])[ir]*np.pi/180 # [rad]
         
         # Rotor shaft tilt and toe angles in directions of pitch and yaw, respectively [rad]
         self.shaft_tilt = getFromDict(turbine, 'shaft_tilt', shape=turbine['nrotors'])[ir]*np.pi/180
@@ -95,8 +89,22 @@ class Rotor:
         
         self.aeroServoMod = getFromDict(turbine, 'aeroServoMod', shape=turbine['nrotors'], default=1)[ir]  # flag for aeroservodynamics (0=none, 1=aero only, 2=aero and control)
 
+        if self.overhang > 0:
+            print("\n\n IMPORTANT WARNING: Now, positive overhang corresponds to DOWNWIND turbines.")
+            print("This is the opposite of some previous RAFT versions.")
+            print("Please specify a negative overhang if you wanted an upwind rotor.\n\n")
+        if self.precone > 0:
+            print("\n\n IMPORTANT WARNING: Now, positive precone is away from the rotor plane for DOWNWIND turbines.")
+            print("This is the opposite of some previous RAFT versions.")
+            print("Please specify a negative precone if you wanted a conventional upwind rotor.\n\n")
+        if self.shaft_tilt > 0:
+            print("\n\n IMPORTANT WARNING: Now, positive shaft_tilt is upwards for DOWNWIND turbines.")
+            print("This is the opposite of some previous RAFT versions.")
+            print("Please specify a negative shaft_tilt if you wanted a conventional upwind rotor.\n\n")
+
+
         # Unit vector of rotor axis, facing downflow [-]. Relative to the FOWT. Includes shaft tilt and initial yaw
-        self.q_rel = np.matmul(rotationMatrix(0, self.shaft_tilt, self.shaft_toe), np.array([1.,0.,0.]) )        
+        self.q_rel = np.matmul(rotationMatrix(0, -self.shaft_tilt, self.shaft_toe), np.array([1.,0.,0.]) )        
         
         # initialize absolute position/orientation variables
         self.r3 = np.zeros(3)  # instantaneous global position of rotor hub location       
@@ -345,11 +353,11 @@ class Rotor:
             self.nBlades,                   # number of blades
             self.rho,                       # (kg/m^3) freestream fluid density
             self.mu,                        # (kg/m/s) dynamic viscosity of fluid
-            self.precone,                   # (deg) hub precone angle
-            np.degrees(self.shaft_tilt),    # (deg) hub tilt angle  
+            np.degrees(-self.precone),                  # (deg) hub precone angle
+            np.degrees(-self.shaft_tilt),   # (deg) hub tilt angle - CCBlade uses a different convention. Positive tilt is a positive rotation about the y-axis (positive for upwind turbines, negative for downwind turbines)
             0.0,                            # (deg) nacelle yaw angle
             self.shearExp,                  # shear exponent for a power-law wind profile across hub
-            self.r3[2],                      # (m) hub height used for power-law wind profile.  U = Uref*(z/hubHt)**shearExp
+            self.r3[2],                     # (m) hub height used for power-law wind profile.  U = Uref*(z/hubHt)**shearExp
             nSector,                        # number of azimuthal sectors to descretize aerodynamic calculation.  automatically set to 1 if tilt, yaw, and shearExp are all 0.0.  Otherwise set to a minimum of 4.
             blade_precurve,                 # (m) location of blade pitch axis in x-direction of :ref:`blade coordinate system <azimuth_blade_coord>`
             turbine['blade'][ir]['precurveTip'],# (m) location of blade pitch axis in x-direction at the tip (analogous to Rtip)
@@ -391,14 +399,12 @@ class Rotor:
         # Store platform heading for use with nacelle yaw
         self.platform_heading = r6[5]
         
-        # Apply nacelle yaw depending on the yaw mode 
-        self.setYaw()
-        
         # Update RNA point locations [m] w.r.t. PRP in global orientations
         self.r_RRP_rel = np.matmul(self.R_ptfm, self.r_rel) # RNA ref point
-        self.r_CG_rel = self.r_RRP_rel + self.q*self.xCG_RNA # RNA CG location
-        self.r_hub_rel = self.r_RRP_rel + self.q*self.overhang # rotor hub location
-        
+
+        # Apply nacelle yaw depending on the yaw mode 
+        self.setYaw()
+                
         '''
         self.r_RRP = ? # RNA reference point
         self.r_CG  = ? # RNA CG location
@@ -450,12 +456,16 @@ class Rotor:
         self.turbine_heading = self.platform_heading + self.yaw
 
         # Rotation matrix from platform local x to rotor axis
-        R_q_rel = rotationMatrix(0, self.shaft_tilt, self.shaft_toe + self.yaw) 
+        R_q_rel = rotationMatrix(0, -self.shaft_tilt, self.shaft_toe + self.yaw) 
         self.R_q = np.matmul(R_q_rel, self.R_ptfm)  # this one's from global x
         
         # Compute shaft axis unit vector in FOWT and global frames 
         self.q_rel = np.matmul(R_q_rel, np.array([1,0,0]) )
         self.q = np.matmul(self.R_ptfm, self.q_rel) # Write in the global frame 
+
+        # Update RNA point locations [m] w.r.t. PRP in global orientations
+        self.r_CG_rel = self.r_RRP_rel + self.q*self.xCG_RNA # RNA CG location
+        self.r_hub_rel = self.r_RRP_rel + self.q*self.overhang # rotor hub location
         
         return self.yaw
     
@@ -636,7 +646,7 @@ class Rotor:
         return A_hydro, I_hydro
 
 
-    def calcCavitation(self, case, azimuth=0, clearance_margin=1.0, Patm=101325, Pvap=2500, error_on_cavitation=False):
+    def calcCavitation(self, case, azimuth=0, clearance_margin=1.0, Patm=101325, Pvap=2300, error_on_cavitation=False):
         ''' Method to calculate the cavitation number of the rotor
         (wind speed (m/s), rotor speed (RPM), pitch angle (deg), azimuth (deg))
 
@@ -690,6 +700,8 @@ class Rotor:
                 
                 cav_check[a,n] = sigma_crit + cpmin_node         # if this value is negative, then cavitation occurs (sigma_crit - sigma_l < 0 -> cav occurs; sigma_l = -cpmin_node)
 
+        if np.any(cav_check < 0.0):
+            print("WARNING: Cavitation check was run and found a blade node that has cavitation occuring")
 
         return cav_check
 
@@ -818,7 +830,7 @@ class Rotor:
         # >>> should double check signs <<<
         
         # call CCBlade
-        loads, derivs = self.runCCBlade(speed, tilt=turbine_tilt,
+        loads, derivs = self.runCCBlade(speed, tilt=-turbine_tilt,
                                         yaw_misalign=yaw_misalign)
 
         # ----- Process derivatives of interest -----
@@ -836,7 +848,7 @@ class Rotor:
         # Set up vectors in axis frame. Assuming CCBlade forces (but not 
         # moments) are relative to the rotor axis
         forces_axis = np.array([loads["T"][0], loads["Y"][0], loads["Z" ][0]])
-        moments_axis = np.array([loads["My"][0], loads["Q"][0], loads["Mz"][0]])        
+        moments_axis = np.array([loads["Q"][0], loads["My"][0], loads["Mz"][0]])        
         
         # Rotate forces and moments to be relative to global orientation (but still wrt hub)
         self.f0[:3] = np.matmul(self.R_q, forces_axis)
@@ -848,14 +860,14 @@ class Rotor:
         _,_,_,S_rot = self.IECKaimal(case, current=current)   # PSD [(m/s)^2/rad]
         
         # convert from power spectral density to complex amplitudes (FFT)
-        self.V_w = np.array(np.sqrt(S_rot), dtype=complex)  # Is there a factor of 2 missing here?
+        self.V_w = np.array(np.sqrt(2*S_rot*(self.w[1]-self.w[0])), dtype=complex)
 
         # Do we need to worry about scaling by dot prod of rotor axis and
         # inflow direction?  *np.cos(turbine_tilt)*np.cos(yaw_misalign) <<<
 
         # Rotate rotor hydro inertial excitation matrix into global frame
-        if current:
-            I_hydro = rotateMatrix6(self.I_hydro, self.R_q)
+        #if current:
+            #I_hydro = rotateMatrix6(self.I_hydro, self.R_q)
 
         # no-control option
         if self.aeroServoMod == 1:  
@@ -868,7 +880,7 @@ class Rotor:
             b_inflow[0,0,:] = dT_dU
             
             # Excitation vector
-            f_inflow = np.zeros([6,len(self.w)], dtype=np.complex_)
+            f_inflow = np.zeros([6,len(self.w)], dtype=np.complex128)
             f_inflow[0,:] = dT_dU*self.V_w
             
             # Rotate to global orientations
@@ -893,10 +905,10 @@ class Rotor:
             
             a_aer = np.zeros_like(self.w)
             b_aer = np.zeros_like(self.w)
-            C   = np.zeros_like(self.w,dtype=np.complex_)
-            C2  = np.zeros_like(self.w,dtype=np.complex_)
-            D   = np.zeros_like(self.w,dtype=np.complex_)
-            E   = np.zeros_like(self.w,dtype=np.complex_)
+            C   = np.zeros_like(self.w,dtype=np.complex128)
+            C2  = np.zeros_like(self.w,dtype=np.complex128)
+            D   = np.zeros_like(self.w,dtype=np.complex128)
+            E   = np.zeros_like(self.w,dtype=np.complex128)
 
             # Roots of characteristic equation, helps w/ debugging
             # p = np.array([-self.I_drivetrain, (dQ_dOm + self.kp_beta * dQ_dPi - self.Ng * kp_tau), self.ki_beta* dQ_dPi - self.Ng * ki_tau])
@@ -905,19 +917,19 @@ class Rotor:
             for iw, omega in enumerate(self.w):
                 
                 # Denominator of control transfer function
-                D[iw] = self.I_drivetrain * omega**2 + (dQ_dOm + self.kp_beta * dQ_dPi - self.Ng * kp_tau) * 1j * omega + self.ki_beta* dQ_dPi - self.Ng * ki_tau
+                D[iw] = self.I_drivetrain * omega**2 + (dQ_dOm[0] + self.kp_beta * dQ_dPi[0] - self.Ng * kp_tau) * 1j * omega + self.ki_beta* dQ_dPi[0] - self.Ng * ki_tau
 
                 # control transfer function
-                C[iw] = 1j * omega * (dQ_dU - self.k_float * dQ_dPi / self.r3[2]) / D[iw]
+                C[iw] = 1j * omega * (dQ_dU[0] - self.k_float * dQ_dPi[0] / self.r3[2]) / D[iw]
 
                 # Thrust transfer function
-                E[iw] = ((dT_dOm + self.kp_beta * dT_dPi) * 1j * omega + self.ki_beta * dT_dPi )
+                E[iw] = ((dT_dOm[0] + self.kp_beta * dT_dPi[0]) * 1j * omega + self.ki_beta * dT_dPi[0] )
 
                 # alternative for debugging
                 C2[iw] = C[iw] / (1j * omega)
 
                 # Complex aero damping
-                T = 1j * omega * (dT_dU - self.k_float * dT_dPi / self.r3[2]) - ( E[iw] * C[iw])
+                T = 1j * omega * (dT_dU[0] - self.k_float * dT_dPi[0] / self.r3[2]) - ( E[iw] * C[iw])
                 
                 # Aerodynamic coefficients
                 a_aer[iw] = -(1/omega**2) * np.real(T)
@@ -945,8 +957,8 @@ class Rotor:
             self.c_exc = dT_dU - H_QT*dQ_dU
 
             f2 = (dT_dU - H_QT*dQ_dU) * self.V_w  # excitation force
-            b2 = np.real(  dT_dU - self.k_float*dT_dPi - H_QT*(dQ_dU - self.k_float*dQ_dPi)             )  # damping
-            a2 = np.real( (dT_dU - self.k_float*dT_dPi - H_QT*(dQ_dU - self.k_float*dQ_dPi))/(1j*self.w))  # added mass
+            b2 = np.real(  dT_dU - self.k_float*dT_dPi/self.r3[2] - H_QT*(dQ_dU - self.k_float*dQ_dPi/self.r3[2])             )  # damping
+            a2 = np.real( (dT_dU - self.k_float*dT_dPi/self.r3[2] - H_QT*(dQ_dU - self.k_float*dQ_dPi/self.r3[2]))/(1j*self.w))  # added mass
 
             # without nacelle feedback
             b3 = np.real(  dT_dU - H_QT*dQ_dU             )  # damping
@@ -992,16 +1004,18 @@ class Rotor:
                 self.b[:3,:3, iw] = rotateMatrix3(np.diag([b2[iw],0,0]), self.R_q)
                 self.f[:3,    iw] = np.matmul(self.R_q, np.array([f2[iw],0,0]))
                 # Above is only forces for now. Moments can be added in future.
-
+        
+        """ # Caltured in FOWT.calcHydroExcitation()
         # Add hydrodynamic inertial excitation for underwater rotors
         if current:
             self.f[0,:] += self.I_hydro[0,0] * 1j*self.w*self.V_w  # <<< this should have a rotation applied
             breakpoint()
+        """        
         
         return self.f0, self.f, self.a, self.b #  B_aero, C_aero, F_aero0, F_aero
         
         
-    def plot(self, ax, r_ptfm=[0,0,0], azimuth=0, color='k', 
+    def plot(self, ax, r_ptfm=np.array([0,0,0]), azimuth=0, color='k', 
              airfoils=False, draw_circle=False,
              plot2d=False, Xuvec=[1,0,0], Yuvec=[0,0,1], zorder=2):
         '''Draws the rotor on the passed axes, considering optional platform 
@@ -1049,9 +1063,9 @@ class Rotor:
         
         # ----- rotation matrices ----- 
         # (blade pitch would be a -rotation about local z)
-        R_precone = rotationMatrix(0, -self.ccblade.precone, 0)  
+        R_precone = rotationMatrix(0, self.precone, 0)  
         R_azimuth = [rotationMatrix(azimuth + azi, 0, 0) for azi in (2*np.pi/self.nBlades)*np.arange(self.nBlades)]
-        R_tilt    = rotationMatrix(0, self.shaft_tilt, 0)   # # define x as along shaft downwind, y is same as ptfm y
+        R_tilt    = rotationMatrix(0, -self.shaft_tilt, 0)   # # define x as along shaft downwind, y is same as ptfm y
         
         # ----- transform coordinates -----
         for ib in range(self.nBlades):
@@ -1059,8 +1073,9 @@ class Rotor:
             P2 = np.matmul(R_precone, P)
             P2 = np.matmul(R_azimuth[ib], P2)  # rotate around shaft
             P2 = np.matmul(self.R_q, P2)  # rotate to actual rotor orientation
-            P2 = P2 + self.r3[:,None] + r_ptfm[:,None]  # translate from PRP to absolute hub location
-          
+            P2 = P2 + self.r3[:,None]  # translate from PRP to absolute hub location
+            
+            
             if plot2d:  # new 2d plotting option
                 
                 # apply any 3D to 2D transformation here to provide desired viewing angle
