@@ -16,8 +16,10 @@ test_dir = 'test_data'
 
 # List of input file names to be tested
 list_files = [
-    'VolturnUS-S.yaml',
     'OC3spar.yaml',
+    'VolturnUS-S.yaml',    
+    'VolturnUS-S-pointInertia.yaml',
+    'OC4semi-WAMIT_Coefs.yaml'
 ]
 
 
@@ -35,76 +37,128 @@ list_files = [os.path.join(current_dir, test_dir, file) for file in list_files]
 '''
 # Structure related quantities
 desired_rCG = [
-    np.array([ 2.34101810e-15,  7.81354773e-16, -2.03398326e+00]),
     np.array([              0,               0, -78.03525272   ]),
+    np.array([-3.78742736e-01,  7.80925410e-16, -1.91132267e+00]),
+    np.array([-3.78616422e-01,  3.80441015e-19, -1.69266625e+00]),
+    np.array([ 4.32611618e-15,  1.08152905e-15, -1.00637502e+01]),
 ]
 desired_rCG_sub = [
-    np.array([ 2.65203563e-15,  8.85162184e-16,  -1.51939447e+01]),
     np.array([              0,               0, -89.91292526    ]),
+    np.array([ 2.65203563e-15,  8.85162184e-16,  -1.51939447e+01]),
+    np.array([ 8.62405052e-19,  4.31202526e-19,  -1.49410924e+01]),
+    np.array([ 4.52296648e-15,  1.13074162e-15,  -1.37215567e+01]),
 ]
 
 desired_m_ballast = [
-    np.array([1.0569497625e+07, 2.42678207158787e+06]),
-    np.array([6.5323524956e+06])
+    np.array([6.5323524956e+06]),
+    np.array([1.0569497625e+07, 2.42678207158787e+06]),    
+    np.array([0.]),
+    np.array([9592105.45682851]),
 ]
 
 desired_M_struc = [
-    np.array([[ 1.91081767e+07,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00, -3.88657114e+07, -1.49302650e-08],
-              [ 0.00000000e+00,  1.91081767e+07,  0.00000000e+00,  3.88657114e+07,  0.00000000e+00,  4.47325874e-08],
-              [ 0.00000000e+00,  0.00000000e+00,  1.91081767e+07,  1.49302650e-08, -4.47325874e-08,  0.00000000e+00],
-              [ 0.00000000e+00,  3.88657114e+07,  1.49302650e-08,  4.22011083e+10,  9.54605639e-07,  4.76371497e-07],
-              [-3.88657114e+07,  0.00000000e+00, -4.47325874e-08,  9.54605639e-07,  4.22011083e+10,  4.76371497e-07],
-              [-1.49302650e-08,  4.47325874e-08,  0.00000000e+00,  5.96046448e-07,  4.76371497e-07,  2.05595816e+10]]),
     np.array([[ 8.08951257e+06,  0.00000000e+00, -3.63797881e-12,  0.00000000e+00, -6.31267158e+08,  0.00000000e+00],
               [ 0.00000000e+00,  8.08951257e+06,  0.00000000e+00,  6.31267158e+08,  0.00000000e+00,  0.00000000e+00],
               [ 3.63797881e-12,  0.00000000e+00,  8.08951257e+06,  0.00000000e+00,  3.25832739e-10,  0.00000000e+00],
               [ 0.00000000e+00,  6.31267158e+08,  0.00000000e+00,  6.77394404e+10,  0.00000000e+00, -8.06082047e+05],
               [-6.31267158e+08,  0.00000000e+00,  3.25832739e-10,  0.00000000e+00,  6.77302268e+10,  0.00000000e+00],
               [ 0.00000000e+00,  0.00000000e+00,  0.00000000e+00, -8.06082047e+05,  0.00000000e+00,  1.18100818e+08]]),
+    np.array([[ 1.91186826e+07,  0.00000000e+00, -7.72177272e-12,  0.00000000e+00, -3.65419714e+07, -1.49302650e-08],
+              [ 0.00000000e+00,  1.91186826e+07,  0.00000000e+00,  3.65419714e+07,  0.00000000e+00, -7.24106215e+06],
+              [ 1.30711139e-11,  0.00000000e+00,  1.91186826e+07,  1.49302650e-08,  7.24106215e+06,  0.00000000e+00],
+              [ 0.00000000e+00,  3.65419714e+07,  1.49302650e-08,  4.26605281e+10,  9.54605639e-07,  1.08255551e+09],
+              [-3.65419714e+07,  0.00000000e+00,  7.24106215e+06,  9.54605639e-07,  4.27128822e+10,  4.76371497e-07],
+              [-1.49302650e-08, -7.24106215e+06,  0.00000000e+00,  1.08255551e+09,  4.76371497e-07,  2.06119358e+10]]),
+    np.array([[ 1.91250610e+07,  0.00000000e+00, -7.72177272e-12,  0.00000000e+00, -3.23723453e+07, -7.27595761e-12],
+              [ 0.00000000e+00,  1.91250610e+07,  0.00000000e+00,  3.23723453e+07,  0.00000000e+00, -7.24106215e+06],
+              [ 1.30711139e-11,  0.00000000e+00,  1.91250610e+07,  7.27595761e-12,  7.24106215e+06,  0.00000000e+00],
+              [ 0.00000000e+00,  3.23723453e+07,  7.27595761e-12,  4.25355736e+10,  2.32830644e-10,  1.08255551e+09],
+              [-3.23723453e+07,  0.00000000e+00,  7.24106215e+06,  2.32830644e-10,  4.25879277e+10,  1.16415322e-10],
+              [-7.27595761e-12, -7.24106215e+06,  0.00000000e+00,  1.08255551e+09,  1.16415322e-10,  2.06187038e+10]]),
+    np.array([[ 1.37778650e+07,  0.00000000e+00, -3.63797881e-12,  0.00000000e+00, -1.38656991e+08, -1.49011612e-08],
+              [ 0.00000000e+00,  1.37778650e+07,  0.00000000e+00,  1.38656991e+08,  0.00000000e+00,  4.47034836e-08],
+              [ 3.63797881e-12,  0.00000000e+00,  1.37778650e+07,  1.49011612e-08, -4.43776508e-08,  0.00000000e+00],
+              [ 0.00000000e+00,  1.38656991e+08,  1.49011612e-08,  1.26568887e+10,  4.76837158e-07, -8.06082047e+05],
+              [-1.38656991e+08,  0.00000000e+00, -4.43776508e-08,  4.76837158e-07,  1.26476751e+10,  2.38418579e-07],
+              [-1.49011612e-08,  4.47034836e-08,  0.00000000e+00, -8.06082047e+05,  2.38418579e-07,  1.22412242e+10]]),
 ]
 
 desired_M_struc_sub = [
+    np.array([[  7.48986700e+06,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00, -6.73435852e+08,  0.00000000e+00],
+              [  0.00000000e+00,  7.48986700e+06,  0.00000000e+00,  6.73435852e+08,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  7.48986700e+06,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  6.73435852e+08,  0.00000000e+00,  6.43071810e+10,  0.00000000e+00,  0.00000000e+00],
+              [ -6.73435852e+08,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  6.43071810e+10,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  9.00523426e+07]]),    
     np.array([[  1.68672649e+07,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00, -2.56280290e+08, -1.49302650e-08],
               [  0.00000000e+00,  1.68672649e+07,  0.00000000e+00,  2.56280290e+08,  0.00000000e+00,  4.47325874e-08],
               [  0.00000000e+00,  0.00000000e+00,  1.68672649e+07,  1.49302650e-08, -4.47325874e-08,  0.00000000e+00],
               [  0.00000000e+00,  2.56280290e+08,  1.49302650e-08,  1.49458996e+10,  9.54605639e-07,  4.76371497e-07],
               [ -2.56280290e+08,  0.00000000e+00, -4.47325874e-08,  9.54605639e-07,  1.49458996e+10,  4.76371497e-07],
               [ -1.49302650e-08,  4.47325874e-08,  0.00000000e+00,  5.96046448e-07,  4.76371497e-07,  2.05313182e+10]]),
-    np.array([[  7.48986700e+06,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00, -6.73435852e+08,  0.00000000e+00],
-              [  0.00000000e+00,  7.48986700e+06,  0.00000000e+00,  6.73435852e+08,  0.00000000e+00,  0.00000000e+00],
-              [  0.00000000e+00,  0.00000000e+00,  7.48986700e+06,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
-              [  0.00000000e+00,  6.73435852e+08,  0.00000000e+00,  6.43071810e+10,  0.00000000e+00,  0.00000000e+00],
-              [ -6.73435852e+08,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  6.43071810e+10,  0.00000000e+00],
-              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  9.00523426e+07]])
+    np.array([[ 1.68736433e+07,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00, -2.52110664e+08, -7.27595761e-12],
+              [ 0.00000000e+00,  1.68736433e+07,  0.00000000e+00,  2.52110664e+08,  0.00000000e+00,  1.45519152e-11],
+              [ 0.00000000e+00,  0.00000000e+00,  1.68736433e+07,  7.27595761e-12, -1.45519152e-11,  0.00000000e+00],
+              [ 0.00000000e+00,  2.52110664e+08,  7.27595761e-12,  1.48209451e+10,  2.32830644e-10,  2.32830644e-10],
+              [-2.52110664e+08,  0.00000000e+00, -1.45519152e-11,  2.32830644e-10,  1.48209451e+10,  1.16415322e-10],
+              [-7.27595761e-12,  1.45519152e-11,  0.00000000e+00,  3.49245965e-10,  1.16415322e-10,  2.05380863e+10]]),
+    np.array([[ 1.31782194e+07,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00, -1.80825686e+08, -1.49011612e-08],
+              [ 0.00000000e+00,  1.31782194e+07,  0.00000000e+00,  1.80825686e+08,  0.00000000e+00,  4.47034836e-08],
+              [ 0.00000000e+00,  0.00000000e+00,  1.31782194e+07,  1.49011612e-08, -4.47034836e-08,  0.00000000e+00],
+              [ 0.00000000e+00,  1.80825686e+08,  1.49011612e-08,  9.22462925e+09,  4.76837158e-07,  2.38418579e-07],
+              [-1.80825686e+08,  0.00000000e+00, -4.47034836e-08,  4.76837158e-07,  9.22462925e+09,  2.38418579e-07],
+              [-1.49011612e-08,  4.47034836e-08,  0.00000000e+00,  4.76837158e-07,  2.38418579e-07,  1.22131757e+10]]),
 ]
 
 desired_C_struc = [
     np.array([[  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
               [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
               [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
-              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  3.81272628e+08,  0.00000000e+00,  0.00000000e+00],
-              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  3.81272628e+08,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  6.19273082e+09,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  6.19273082e+09,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00]]),    
+    np.array([[  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  3.58476739e+08,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  3.58476739e+08,  0.00000000e+00],
               [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00]]),
     np.array([[  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
               [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
               [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
-              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  6.19273082e+09,  0.00000000e+00,  0.00000000e+00],
-              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  6.19273082e+09,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  3.17572707e+08,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  3.17572707e+08,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00]]),
+    np.array([[  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  1.36022508e+09,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  1.36022508e+09,  0.00000000e+00],
               [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00]]),
 ]
 
 desired_W_struc = [
-    np.array([  0.00000000e+00,  0.00000000e+00, -1.87451213e+08, -2.38651410e-07,  3.58093530e-07,  0.00000000e+00]),
     np.array([  0.00000000e+00,  0.00000000e+00, -7.93581183e+07,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00]),
+    np.array([  0.00000000e+00,  0.00000000e+00, -1.87554276e+08, -2.38651410e-07, -7.10348197e+07,  0.00000000e+00]),
+    np.array([  0.00000000e+00,  0.00000000e+00, -1.87616848e+08, -5.82076609e-11, -7.10348197e+07,  0.00000000e+00]),
+    np.array([  0.00000000e+00,  0.00000000e+00, -1.35160856e+08, -1.19209290e-07,  4.76837158e-07,  0.00000000e+00]),
 ]
 
 # Hydrostatic quantities
 desired_rCB = [
-    np.array([ 3.04454348e-15,  1.52227174e-15, -1.35855138e+01]),
     np.array([ 0.00000000e+00,  0.00000000e+00, -6.20656552e+01]),
+    np.array([ 3.04454348e-15,  1.52227174e-15, -1.35855138e+01]),
+    np.array([ 3.04454348e-15,  1.52227174e-15, -1.35855138e+01]),
+    np.array([ 2.14681350e-15,  1.07340675e-15, -1.31534674e+01])
 ]
 
 desired_C_hydro = [
+    np.array([[  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  3.33664089e+05,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00, -5.01003340e+09,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00, -5.01003340e+09,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00]]),
     np.array([[  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
               [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
               [  0.00000000e+00,  0.00000000e+00,  4.30992285e+06, -7.45058060e-09,  2.23517418e-08,  0.00000000e+00],
@@ -113,52 +167,59 @@ desired_C_hydro = [
               [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00]]),
     np.array([[  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
               [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
-              [  0.00000000e+00,  0.00000000e+00,  3.33664089e+05,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
-              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00, -5.01003340e+09,  0.00000000e+00,  0.00000000e+00],
-              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00, -5.01003340e+09,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  4.30992285e+06, -7.45058060e-09,  2.23517418e-08,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00, -7.45058060e-09,  2.17117691e+09, -4.76837158e-07,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  2.23517418e-08, -4.76837158e-07,  2.17117691e+09,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00]]),
+    np.array([[  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  3.74533004e+06, -3.72529030e-09,  1.11758709e-08,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00, -3.72529030e-09, -3.40662111e+08, -1.19209290e-07,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  1.11758709e-08, -1.19209290e-07, -3.40662111e+08,  0.00000000e+00],
               [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00]]),
 ]
 
 desired_W_hydro = [
+    np.array([ 0.00000000e+00,  0.00000000e+00,  8.07357058e+07,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00]),
+    np.array([ 0.00000000e+00,  0.00000000e+00,  1.92243134e+08,  2.38418579e-07, -3.57627869e-07,  0.00000000e+00]),    
     np.array([ 0.00000000e+00,  0.00000000e+00,  1.92243134e+08,  2.38418579e-07, -3.57627869e-07,  0.00000000e+00]),
-    np.array([ 0.00000000e+00,  0.00000000e+00,  8.07357058e+07,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00])
+    np.array([ 0.00000000e+00,  0.00000000e+00,  1.36316588e+08,  2.38418579e-07, -2.38418579e-07,  0.00000000e+00]),
 ]
 
 
 # Hydrodynamic quantities
 desired_A_hydro_morison = [
+    np.array([[  8.22881104e+06,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00, -5.10692712e+08,  0.00000000e+00],
+              [  0.00000000e+00,  8.22881104e+06,  0.00000000e+00,  5.10692712e+08,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  2.23242607e+05,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  5.10692712e+08,  0.00000000e+00,  4.09467123e+10,  0.00000000e+00,  0.00000000e+00],
+              [ -5.10692712e+08,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  4.09467123e+10,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00]]),    
     np.array([[  1.23332103e+07,  4.65661287e-10,  0.00000000e+00,  7.45058060e-09, -1.54950929e+08, -2.98023224e-08],
               [  4.65661287e-10,  1.23332103e+07, -2.58493941e-26,  1.54950929e+08, -7.45058060e-09,  7.45058060e-08],
               [  0.00000000e+00, -2.58493941e-26,  1.09392236e+07,  1.49011612e-08, -1.49011612e-08, -9.18354962e-41],
               [  7.45058060e-09,  1.54950929e+08,  1.49011612e-08,  7.44302567e+09,  3.57627869e-07,  9.53674316e-07],
               [ -1.54950929e+08, -7.45058060e-09, -1.49011612e-08,  3.57627869e-07,  7.44302567e+09,  4.76837158e-07],
               [ -2.98023224e-08,  7.45058060e-08, -9.18354962e-41,  8.34465027e-07,  4.76837158e-07,  2.39620560e+10]]),
-    np.array([[  8.22881104e+06,  0.00000000e+00,  0.00000000e+00, 0.00000000e+00,  -5.10692712e+08,  0.00000000e+00],
-              [  0.00000000e+00,  8.22881104e+06,  0.00000000e+00, 5.10692712e+08,   0.00000000e+00,  0.00000000e+00],
-              [  0.00000000e+00,  0.00000000e+00,  2.23242607e+05, 0.00000000e+00,   0.00000000e+00,  0.00000000e+00],
-              [  0.00000000e+00,  5.10692712e+08,  0.00000000e+00, 4.09467123e+10,   0.00000000e+00,  0.00000000e+00],
-              [ -5.10692712e+08,  0.00000000e+00,  0.00000000e+00, 0.00000000e+00,   4.09467123e+10,  0.00000000e+00],
-              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00, 0.00000000e+00,   0.00000000e+00,  0.00000000e+00]])
-]
-
-desired_F_hydro_iner = [
-    np.array([[[  0.00000000e+00+0.00000000e+00j,  5.27862388e-06+3.55202739e-04j,  2.70437607e+03+7.13012568e+04j,  1.39204693e+05+1.20341600e+06j,  6.19003712e+05+1.45322648e+06j,  1.26581615e+06+5.38094639e+05j,  1.54066254e+06-1.06700055e+05j,  9.73449433e+05-1.54735127e+05j, -7.25098731e+04-1.53049868e+05j, -5.50225753e+05-2.51854400e+05j],
-               [  0.00000000e+00+0.00000000e+00j,  0.00000000e+00-6.77626358e-21j,  0.00000000e+00-9.09494702e-13j,  2.91038305e-11+0.00000000e+00j, -2.91038305e-11-1.45519152e-11j, -5.09317033e-11+2.91038305e-11j,  0.00000000e+00-2.18278728e-11j,  7.27595761e-12-1.81898940e-11j, -3.63797881e-12-9.09494702e-13j,  0.00000000e+00+1.36424205e-12j],
-               [  0.00000000e+00+0.00000000e+00j,  4.36781698e-04-1.06335971e-06j,  1.12590567e+04-7.39559352e+02j, -3.67100235e+05-3.03329514e+04j, -9.33433420e+05-5.29491702e+04j, -7.56882469e+05+4.71609883e+04j, -3.08614019e+05+2.21762147e+05j, -3.10898556e+04+3.10700182e+05j,  4.30529645e+04+2.41235701e+05j,  4.57382992e+04+1.05934499e+05j],
-               [  0.00000000e+00+0.00000000e+00j,  1.95156391e-18+4.87890978e-19j,  8.73114914e-11+4.36557457e-11j,  9.31322575e-10+9.31322575e-10j, -9.31322575e-10+1.86264515e-09j, -1.39698386e-09-9.31322575e-10j, -2.03726813e-10-8.14907253e-10j,  5.82076609e-10+0.00000000e+00j,  3.20142135e-10-1.09139364e-10j,  1.45519152e-11+5.09317033e-11j],
-               [  0.00000000e+00+0.00000000e+00j, -5.25125306e-04-1.13258648e-04j, -1.88802798e+05-2.34251669e+05j, -5.03535064e+06-9.34753238e+06j, -9.66951530e+06-2.29999628e+07j, -9.07389415e+06-2.31167534e+07j, -7.24707025e+06-1.36646621e+07j, -4.98264131e+06-4.74474286e+06j, -1.64674075e+06-6.23579171e+04j,  4.05694750e+05+1.24236863e+06j],
-               [  0.00000000e+00+0.00000000e+00j,  1.49077799e-19-2.71050543e-19j, -1.81898940e-11+7.27595761e-12j,  1.51339918e-09-6.98491931e-10j,  0.00000000e+00+1.16415322e-09j, -1.62981451e-09+1.97906047e-09j,  3.02679837e-09-1.48429535e-09j, -7.56699592e-10+5.23868948e-10j,  1.13504939e-09+9.24046617e-10j, -4.36557457e-11-9.31322575e-10j]]]),
-    np.array([[[  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+1.29014243e-04j,  0.00000000e+00+2.18136450e+04j,  0.00000000e+00+3.20625334e+05j,  0.00000000e+00+4.47063970e+05j,  0.00000000e+00+3.72186312e+05j,  0.00000000e+00+2.73435771e+05j,  0.00000000e+00+1.96646986e+05j,  0.00000000e+00+1.42846361e+05j,  0.00000000e+00+1.05877244e+05j],
-               [  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j],
-               [  0.00000000e+00+0.00000000e+00j, -3.83018423e-06+0.00000000e+00j, -4.39079984e+03+0.00000000e+00j, -7.61182325e+04+0.00000000e+00j, -1.07109629e+05+0.00000000e+00j, -8.59303021e+04+0.00000000e+00j, -5.94885784e+04+0.00000000e+00j, -3.95278075e+04+0.00000000e+00j, -2.59659374e+04+0.00000000e+00j, -1.70032358e+04+0.00000000e+00j],
-               [  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j],
-               [  0.00000000e+00+0.00000000e+00j,  0.00000000e+00-7.11328048e-03j,  0.00000000e+00-1.01290133e+06j,  0.00000000e+00-1.16863323e+07j,  0.00000000e+00-1.21895057e+07j,  0.00000000e+00-7.55633166e+06j,  0.00000000e+00-4.23360829e+06j,  0.00000000e+00-2.38627057e+06j,  0.00000000e+00-1.38694212e+06j,  0.00000000e+00-8.34570909e+05j],
-               [  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j,  0.00000000e+00+0.00000000e+00j]]])
+    np.array([[  1.23332103e+07,  4.65661287e-10,  0.00000000e+00,  7.45058060e-09, -1.54950929e+08, -2.98023224e-08],
+              [  4.65661287e-10,  1.23332103e+07, -2.58493941e-26,  1.54950929e+08, -7.45058060e-09,  7.45058060e-08],
+              [  0.00000000e+00, -2.58493941e-26,  1.09392236e+07,  1.49011612e-08, -1.49011612e-08, -9.18354962e-41],
+              [  7.45058060e-09,  1.54950929e+08,  1.49011612e-08,  7.44302567e+09,  3.57627869e-07,  9.53674316e-07],
+              [ -1.54950929e+08, -7.45058060e-09, -1.49011612e-08,  3.57627869e-07,  7.44302567e+09,  4.76837158e-07],
+              [ -2.98023224e-08,  7.45058060e-08, -9.18354962e-41,  8.34465027e-07,  4.76837158e-07,  2.39620560e+10]]),
+    np.array([[  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00],
+              [  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00,  0.00000000e+00]])
 ]
 
 desired_current_drag = [
+    np.array([1.66747692e+06, 4.46799093e+05,        0.0e+00, 2.67342887e+07, -9.97737237e+07,        0.0e+00]),
+    np.array([2.64655964e+06, 6.47726496e+05, 7.60648090e-27, 8.77357984e+06, -3.65254345e+07, 1.15751779e+07]),    
     np.array([2.64655964e+06, 6.47726496e+05, 7.60648090e-27, 8.77357984e+06, -3.65254345e+07, 1.15751779e+07]),
-    np.array([1.66747692e+06, 4.46799093e+05,        0.0e+00, 2.67342887e+07, -9.97737237e+07,        0.0e+00])
+    np.array([1.33618347e+06, 3.58029281e+05, 0.00000000e+00, 4.22548271e+06, -1.57697162e+07, -3.72529030e-09]),
 ]
 
 '''
@@ -170,6 +231,10 @@ desired_current_drag = [
 def create_fowt(file):
     with open(file) as f:
         design = yaml.load(f, Loader=yaml.FullLoader)        
+
+    if 'hydroPath' in design['platform']:
+        design['platform']['hydroPath'] = os.path.join(current_dir, test_dir, design['platform']['hydroPath'])
+
     fowt = raft.Model(design).fowtList[0]
     fowt.setPosition(np.zeros(6))
     fowt.calcStatics()
@@ -283,6 +348,61 @@ def test_calcCurrentLoads(index_and_fowt):
 
     assert_allclose(D, desired_current_drag[index], rtol=1e-05, atol=1e-3)
 
+def test_calcQTF_slenderBody(index_and_fowt, flagSaveValues=False):    
+    # Set flagSaveValues to true to replace the true values file with the values calculated below    
+    index, fowt = index_and_fowt      
+
+    if fowt.potSecOrder == 1: # Check only cases that compute the QTFs
+        true_values_file = list_files[index].replace('.yaml', '_true_calcQTF_slenderBody.pkl')
+        
+        testCase = {'wave_heading': 30, 'wave_period': 12, 'wave_height': 6} # Testing one case only
+        fowt.calcHydroConstants() # Need to call this one before calcHydroExcitation
+        fowt.calcHydroExcitation(testCase, memberList=fowt.memberList) # Need to call this one before calcQTF_slenderBody
+        fowt.calcQTF_slenderBody(0) # Testing for the body considered to be fixed. test_model.py should take care of cases with motion
+
+        if flagSaveValues:
+            true_values={
+                'case': testCase,
+                'qtf': fowt.qtf,
+            }
+        else:
+            with open(true_values_file, 'rb') as f:
+                true_values = pickle.load(f)
+            assert_allclose(fowt.qtf, true_values['qtf'], rtol=1e-05, atol=1e-3)
+
+        if flagSaveValues:
+            with open(true_values_file, 'wb') as f:
+                pickle.dump(true_values, f)
+
+def test_calcBEM(index_and_fowt, flagSaveValues=False):    
+    # Set flagSaveValues to true to replace the true values file with the values calculated below    
+    index, fowt = index_and_fowt      
+    
+    # Only test cases that include potential flow coefficients
+    if fowt.potMod:
+        true_values_file = list_files[index].replace('.yaml', '_true_BEM_forces.pkl')
+        
+        testCase = {'wave_heading': 30, 'wave_period': 12, 'wave_height': 6} # Testing one case only
+        fowt.calcBEM() # Need to call this one before calcHydroExcitation
+
+        if flagSaveValues:
+            true_values={
+                'case': testCase,
+                'X_BEM': fowt.X_BEM,
+                'A_BEM': fowt.A_BEM,
+                'B_BEM': fowt.B_BEM,
+            }
+        else:
+            with open(true_values_file, 'rb') as f:
+                true_values = pickle.load(f)
+            assert_allclose(fowt.X_BEM, true_values['X_BEM'], rtol=1e-05, atol=1e-3)
+            assert_allclose(fowt.A_BEM, true_values['A_BEM'], rtol=1e-05, atol=1e-3)
+            assert_allclose(fowt.B_BEM, true_values['B_BEM'], rtol=1e-05, atol=1e-3)
+
+        if flagSaveValues:
+            with open(true_values_file, 'wb') as f:
+                pickle.dump(true_values, f)                
+
 
 '''
  To run as a script. Useful for debugging.
@@ -297,11 +417,16 @@ if __name__ == "__main__":
     test_hydroConstants((index,fowt))
 
     fowt = create_fowt(list_files[index])
-    test_hydroExcitation((index,fowt))
+    test_hydroExcitation((index,fowt), flagSaveValues=False)
 
     fowt = create_fowt(list_files[index])
-    test_hydroLinearization((index,fowt))
+    test_hydroLinearization((index,fowt), flagSaveValues=False)
 
     fowt = create_fowt(list_files[index])
     test_calcCurrentLoads((index,fowt))
 
+    fowt = create_fowt(list_files[index])
+    test_calcQTF_slenderBody((index,fowt), flagSaveValues=False)
+
+    fowt = create_fowt(list_files[index])
+    test_calcBEM((index,fowt), flagSaveValues=False)
